@@ -4,7 +4,7 @@ use Moo;
 use strictures 2;
 use namespace::clean;
 #
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 #
 use WiringPi::API;
 #
@@ -107,20 +107,15 @@ RPi::UnicornHatHD - Use Pimoroni's Awesome Unicorn HAT HD in Perl
 	my $display = RPi::UnicornHatHD->new();
 	while (1) { # Mini rave!
 		$display->set_all(sprintf '#%06X', int rand(hex 'FFFFFF'));
-		for (0 .. 100) {
-			$display->brightness($_ / 100);
-			$display->show();
-		}
-		for (reverse 0 .. 100) {
+		for (0 .. 100, reverse 0 .. 100) {
 			$display->brightness($_ / 100);
 			$display->show();
 		}
 	}
 
-
 =head1 DESCRIPTION
 
-Pimoroni's Unicorn HAT HD crams 256 RGB LEDs, in a 16x16 matrix, onto a single HAT. Use it for scrolling news or stock quotes. Mount it somewhere as a mood light. Build a binary clock. Uh. I don't know, you'll think of something.
+Pimoroni's Unicorn HAT HD crams 256 RGB LEDs, in a 16x16 matrix, onto a single HAT for your Raspberry Pi. Use it for scrolling news or stock quotes. Mount it somewhere as a mood light. Build a binary clock. Uh. I don't know, you'll think of something.
 
 =head1 METHODS
 
@@ -216,11 +211,11 @@ Outputs the contents of the matrix buffer to your Unicorn HAT HD.
 
 =over
 
-=item * Buy one: http://shop.pimoroni.com/products/unicorn-hat-hd
+=item * Buy one: L<http://shop.pimoroni.com/products/unicorn-hat-hd>
 
-=item * GPIO Pinout: http://pinout.xyz/pinout/unicorn_hat_hd
+=item * GPIO Pinout: L<http://pinout.xyz/pinout/unicorn_hat_hd>
 
-=item * Github: https://github.com/sanko/RPi-UnicornHatHD
+=item * Github: L<https://github.com/sanko/RPi-UnicornHatHD>
 
 =back
 
